@@ -3,7 +3,7 @@ package Env::Heroku;
 our $AUTHORITY = 'cpan:PNU';
 # ABSTRACT: set Heroku add-on specific environment variables
 
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 __END__
 
@@ -17,7 +17,7 @@ Env::Heroku - set Heroku add-on specific environment variables
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -39,21 +39,21 @@ version 0.002
 
 =head1 DESCRIPTION
 
-    Set Heroku add-on specific environment variables from Heroku
-    config environment variables to the respective default variables.
+Set Heroku add-on specific environment variables from Heroku
+config environment variables to the respective default variables.
 
-    For example Env::Heroku::Pg will unpack the DATABASE_URL env
-    postgres://user:password@hostname:port/database to env variables
-    PGUSER, PGPASSWORD, PGHOST, PGPORT and PGDATABASE and respective DBI_*
-    variables.
+For example C<Env::Heroku::Pg> will unpack the DATABASE_URL env
+C<postgres://user:password@hostname:port/database> to env variables
+PGUSER, PGPASSWORD, PGHOST, PGPORT and PGDATABASE and respective DBI_*
+variables.
 
-    This allows site configuration to NOT specify database connection info
-    in configuration files that are under version control, but use the Heroku
-    env/config pattern to manage such attached resources.
+This allows site configuration to NOT specify database connection info
+in configuration files that are under version control, but use the Heroku
+env/config pattern to manage such attached resources.
 
 =head1 SEE ALSO
 
-    http://12factor.net/
+L<http://12factor.net/>
 
 =head1 AUTHOR
 
